@@ -265,7 +265,7 @@ if (isset($_POST["add"])) {
             result_log(OPERATION . ":NG:" . $log_msg);
         } else {
             result_log(OPERATION . ":OK:" . $log_msg);
-            $err_msg = htmlspecialchars($err_msg);
+            $err_msg = escape_html($err_msg);
         }
 
     } else {
@@ -321,7 +321,7 @@ if ($ret == LDAP_ERR_NODATA) {
 /* ᡼󥰥ꥹȥɥ쥹ݻ */
 $newml = "";
 if (isset($_POST["newml"])) {
-    $newml = htmlspecialchars($_POST["newml"]);
+    $newml = escape_html($_POST["newml"]);
 }
 
 /* ɽѤLDAP° */
@@ -335,9 +335,9 @@ reset($result);
 $mladdrs = "";
 foreach($result as $i) {
     $mldisp = $i["$displayml"][0];
-    $mldisp = htmlspecialchars($mldisp);
+    $mldisp = escape_html($mldisp);
     $mladdr = $i["mail"][0];
-    $mladdr = htmlspecialchars($mladdr);
+    $mladdr = escape_html($mladdr);
     $mladdrs .= "<option value=\"$mladdr\">$mldisp" . "\n";
 }
 
@@ -345,7 +345,7 @@ foreach($result as $i) {
 set_tag_common($tag, "");
 $tag["<<MLADDRS>>"] = $mladdrs;
 $tag["<<NEWML>>"] = $newml;
-$tag["<<MLDOMAIN>>"] = htmlspecialchars($domain);
+$tag["<<MLDOMAIN>>"] = escape_html($domain);
 
 /* ڡν */
 $ret = display(TMPLFILE, $tag, array(), "", "");
