@@ -251,7 +251,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
 
     // CSVեηå
     if (check_userdata($userdata) === FALSE) {
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -266,7 +266,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* եåѽʣå */
     if (isset($_POST["fcheck"])) {
         if (fcheck_add_user_duplicate($userdata, $fcheckuser) === FALSE) {
-            printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+            printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
@@ -290,7 +290,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* 桼νʣå */
     $ret = csv_check_duplicate($userdata["mail"], $ds);
     if ($ret == LDAP_ERRUSER) {
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -312,7 +312,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         $ret == LDAP_FOUNDALIAS || $ret == LDAP_FOUNDOTHER) {
         $err_msg = $msgarr['14001'][SCREEN_MSG];
         $log_msg = $msgarr['14001'][LOG_MSG];
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -329,7 +329,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         $userdata["mailalias"] = $userdata["alias"] . "@" . $domain;
         $ret = csv_check_duplicate($userdata["mailalias"], $ds);
         if ($ret == LDAP_ERRUSER) {
-            printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+            printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
@@ -344,7 +344,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         if ($ret == LDAP_FOUNDUSER || $ret == LDAP_FOUNDOTHER) {
             $err_msg = $msgarr['14002'][SCREEN_MSG];
             $log_msg = $msgarr['14002'][LOG_MSG];
-            printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+            printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
@@ -363,7 +363,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
     if ($quotalen > $web_conf[$url_data["script"]]["quotasize"]) {
         $err_msg = $msgarr['14004'][SCREEN_MSG];
         $log_msg = $msgarr['14004'][LOG_MSG];
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -377,7 +377,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
 
     /* žɥ쥹Υå */
     if (check_csv_trans($userdata) === FALSE) {
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -394,7 +394,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         /* LDAPɲ */
         if (isset($_POST["upload"])) {
             if (add_user_connect($userdata, $ds) === FALSE) {
-                printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+                printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                        $err_msg);
                 ob_flush();
                 flush();
@@ -420,7 +420,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
                 // sieveեκ˼Ԥϲ̺ɽ
                 if ($ret === FALSE) {
                     $err_msg = $msgarr['26011'][SCREEN_MSG];
-                    printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"])                           , $err_msg);
+                    printf(CSV_NG_MSG, $line, escape_html($userdata["uid"])                           , $err_msg);
                     ob_flush();
                     flush();
                     result_log($logstr . ":NG:" .  $userdata["uid"] .
@@ -437,7 +437,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             $err_msg = $msgarr['14014'][SCREEN_MSG];
             $log_msg = $msgarr['14014'][LOG_MSG];
         }
-        printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_OK_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":OK:" . $userdata["uid"] .
@@ -447,7 +447,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         // LDAPѹ
         if (isset($_POST["upload"])) {
             if (mod_user_connect($userdata, $ds) === FALSE) {
-                printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+                printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                        $err_msg);
                 ob_flush();
                 flush();
@@ -485,7 +485,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
             $err_msg = $msgarr['14015'][SCREEN_MSG];
             $log_msg = $msgarr['14015'][LOG_MSG];
         }
-        printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_OK_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":OK:" . $userdata["uid"] .
@@ -527,7 +527,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     if ($userdata["uid"] == "") {
         $err_msg = $msgarr['14007'][SCREEN_MSG];
         $log_msg = $msgarr['14007'][LOG_MSG];
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -542,7 +542,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* եå¸ߥå */
     if (isset($_POST["fcheck"])) {
         if (is_fcheck_del_user($userdata, $fcheckuser) === FALSE) {
-            printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+            printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
@@ -565,7 +565,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     if (get_userdata_connect($userdn, $ds) === FALSE) {
         $err_msg = $msgarr['14003'][SCREEN_MSG];
         $log_msg = $msgarr['14003'][LOG_MSG];
-        printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+        printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":NG:" . $userdata["uid"] .
@@ -580,7 +580,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     /* LDAP */
     if (isset($_POST["upload"])) {
         if (del_user_connect($userdata["uid"], $ds) === FALSE) {
-            printf(CSV_NG_MSG, $line, htmlspecialchars($userdata["uid"]),
+            printf(CSV_NG_MSG, $line, escape_html($userdata["uid"]),
                    $err_msg);
             ob_flush();
             flush();
@@ -601,7 +601,7 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
     }
 
     /*  */
-    printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
+    printf(CSV_OK_MSG, $line, escape_html($userdata["uid"]), $err_msg);
     ob_flush();
     flush();
     result_log($logstr . ":OK:" . $userdata["uid"] . ":$log_msg(line ${line})");
